@@ -1,15 +1,16 @@
 import argparse
+from argparse import Namespace
 import asyncio
 import logging
 from pathlib import Path
-from argparse import Namespace
+import sys
 
 from colorama import Fore
 from yarl import URL
 
 from . import __version__ as VERSION
 from .utils.base_functions import clear, log, logger, purge_dir, regex_links
-from .utils.data_classes import AuthData
+from .utils.data_classes import AuthData, SkipData
 from .utils.downloaders import get_downloaders
 from .utils.scraper import scrape
 from .utils.sql_helper import SQLHelper
@@ -21,8 +22,7 @@ def parse_args():
     parser.add_argument("-i", "--input-file", type=Path, help="file containing links to download", default="URLs.txt")
     parser.add_argument("-o", "--output-folder", type=Path, help="folder to download files to", default="Downloads")
     parser.add_argument("--log-file", help="log file to write to", default="downloader.log")
-    parser.add_argument("--db-file", help="history database file to write to",
-                        default="download_history.sqlite")
+    parser.add_argument("--db-file", help="history database file to write to", default="download_history.sqlite")
     parser.add_argument("--threads", type=int, help="number of threads to use (0 = max)", default=0)
     parser.add_argument("--attempts", type=int, help="number of attempts to download each file", default=10)
     parser.add_argument("--disable-attempt-limit", help="disables the attempt limitation", action="store_true")
@@ -32,10 +32,25 @@ def parse_args():
     parser.add_argument("--exclude-audio", help="skip downloading of audio files", action="store_true")
     parser.add_argument("--exclude-other", help="skip downloading of images", action="store_true")
     parser.add_argument("--ignore-history", help="This ignores previous download history", action="store_true")
-    parser.add_argument("--separate-posts", help="separates thotsbay scraping into folders by post",
-                        action="store_true")
+    parser.add_argument("--separate-posts", help="Separates thotsbay scraping into folders by post number", action="store_true")
     parser.add_argument("--thotsbay-username", type=str, help="username to login to thotsbay", default=None)
     parser.add_argument("--thotsbay-password", type=str, help="password to login to thotsbay", default=None)
+    parser.add_argument("--skip-anonfiles", help="This removes anonfile links from downloads", action="store_true")
+    parser.add_argument("--skip-bunkr", help="This removes bunkr links from downloads", action="store_true")
+    parser.add_argument("--skip-coomer", help="This removes coomer links from downloads", action="store_true")
+    parser.add_argument("--skip-cyberdrop", help="This removes cyberdrop links from downloads", action="store_true")
+    parser.add_argument("--skip-cyberfile", help="This removes cyberfile links from downloads", action="store_true")
+    parser.add_argument("--skip-erome", help="This removes erome links from downloads", action="store_true")
+    parser.add_argument("--skip-gfycat", help="This removes gfycat links from downloads", action="store_true")
+    parser.add_argument("--skip-gofile", help="This removes gofile links from downloads", action="store_true")
+    parser.add_argument("--skip-jpgchurch", help="This removes jpg.church links from downloads", action="store_true")
+    parser.add_argument("--skip-kemono", help="This removes kemono links from downloads", action="store_true")
+    parser.add_argument("--skip-pixeldrain", help="This removes pixeldrain links from downloads", action="store_true")
+    parser.add_argument("--skip-pixl", help="This removes pixl links from downloads", action="store_true")
+    parser.add_argument("--skip-putmega", help="This removes putmega links from downloads", action="store_true")
+    parser.add_argument("--skip-redgif", help="This removes redgif links from downloads", action="store_true")
+    parser.add_argument("--skip-saint", help="This removes saint.to links from downloads", action="store_true")
+
     parser.add_argument("links", metavar="link", nargs="*",
                         help="link to content to download (passing multiple links is supported)", default=[])
     args = parser.parse_args()
@@ -63,7 +78,12 @@ async def download_all(args: argparse.Namespace):
     with open(input_file, "r", encoding="utf8") as f:
         links += await regex_links(f.read())
     thotsbay_auth = AuthData(args.thotsbay_username, args.thotsbay_password)
-    content_object = await scrape(links, args.include_id, thotsbay_auth, args.separate_posts)
+    skip_data = SkipData()
+    await skip_data.add_skips(args.skip_anonfiles, args.skip_bunkr, args.skip_coomer, args.skip_cyberdrop,
+                              args.skip_cyberfile, args.skip_erome, args.skip_gfycat, args.skip_gofile,
+                              args.skip_jpgchurch, args.skip_kemono, args.skip_pixeldrain, args.skip_pixl,
+                              args.skip_putmega, args.skip_redgif, args.skip_saint)
+    content_object = await scrape(links, args.include_id, thotsbay_auth, args.separate_posts, skip_data)
     if await content_object.is_empty():
         logging.error(f'ValueError No links')
         await log("No links found, check the URL.txt\nIf the link works in your web browser, "
@@ -81,14 +101,14 @@ async def download_all(args: argparse.Namespace):
         await downloader.download_content()
     logger.debug("Finished")
 
-    all_files = [str(f) for f in args.output_folder.glob("**/*") if f.is_file()]
-    combined = '\t'.join(all_files)
+    partial_downloads = [f for f in args.output_folder.glob("*.part") if f.is_file()]
+    combined = '\t'.join(partial_downloads)
 
     await log('Purging empty directories')
-    deleted = await purge_dir(args.output_folder)
+    await purge_dir(args.output_folder)
 
     await log('Finished downloading. Enjoy :)')
-    if '.part' in combined:
+    if partial_downloads:
         await log('There are still partial downloads in your folders, please re-run the program.')
 
 
@@ -101,7 +121,14 @@ def main(args=None):
         format="%(asctime)s:%(levelname)s:%(module)s:%(filename)s:%(lineno)d:%(message)s",
         filemode="w"
     )
-    asyncio.get_event_loop().run_until_complete(download_all(args))
+    if sys.version_info[0] == 3 and sys.version_info[1] >= 8 and sys.platform.startswith('win'):
+        asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+
+    loop = asyncio.get_event_loop()
+    loop.run_until_complete(download_all(args))
+    loop.run_until_complete(asyncio.sleep(1))
+    loop.close()
+
 
 
 if __name__ == '__main__':
